<?php

/* --------------------------------------------------------------
  CustomerGroupServiceFactory.inc.php 2017-09-08
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2017 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------
*/

/**
 * Class CustomerGroupServiceFactory
 * *
 * @category   System
 * @package    CustomerGroup
 * @subpackage Factories
 */
class CustomerGroupServiceFactory
{
	/**
	 * @var \CI_DB_query_builder
	 */
	protected $queryBuilder;
	
	/**
	 * @var \CustomerGroupAccessRepository
	 */
	protected $accessRepository;
	
	/**
	 * @var \CustomerGroupWriteServiceInterface
	 */
	protected $writeService;
	
	/**
	 * @var \CustomerGroupReadServiceInterface
	 */
	protected $readerService;
	
	
	/**
	 * CustomerGroupServiceFactory constructor.
	 *
	 * @param \CI_DB_query_builder $queryBuilder for database connection.
	 */
	public function __construct(CI_DB_query_builder $queryBuilder)
	{
		$this->queryBuilder = $queryBuilder;
	}
	
	
	/**
	 * Creates a customer group write service.
	 *
	 * @return  \CustomerGroupWriteServiceInterface
	 */
	public function createWriteService()
	{
		$this->_createWriter();
		
		return $this->writeService;
	}
	
	
	/**
	 * Creates a customer group read service.
	 *
	 * @return  \CustomerGroupReadServiceInterface
	 */
	public function createReadService()
	{
		$this->_createRepository();
		$this->_createReader();
		
		return $this->readerService;
	}
	
	
	/**
	 * Creates a new instance of a CustomerGroupRepository object.
	 * Consecutive calls provide the same object.
	 *
	 * @return \CustomerGroupAccessRepository
	 */
	protected function _createRepository()
	{
		if(null === $this->accessRepository)
		{
			$languageProvider = MainFactory::create('LanguageProvider', $this->queryBuilder);
			$writer           = MainFactory::create('CustomerGroupWriter', $this->queryBuilder, $languageProvider);
			$deleter          = MainFactory::create('CustomerGroupDeleter', $this->queryBuilder);
			$repository       = MainFactory::create('CustomerGroupRepository', $writer, $deleter);
			$reader           = MainFactory::create('CustomerGroupReader', $this->queryBuilder);
			$factory          = MainFactory::create('CustomerGroupFactory', $repository);
			
			$this->accessRepository = MainFactory::create('CustomerGroupAccessRepository', $factory, $reader,
			                                              $languageProvider);
		}
		
		return $this->accessRepository;
	}
	
	
	/**
	 * Creates a new instance of a CustomerGroupReadService object.
	 * Consecutive calls provide the same object.
	 *
	 * @return \CustomerGroupReadServiceInterface
	 */
	protected function _createReader()
	{
		if(null === $this->readerService)
		{
			$this->readerService = MainFactory::create('CustomerGroupReadService', $this->accessRepository);
		}
		
		return $this->readerService;
	}
	
	
	/**
	 * Creates a new instance of a CustomerGroupWritService object.
	 * Consecutive calls provide the same object.
	 *
	 * @return \CustomerGroupWriteServiceInterface
	 */
	protected function _createWriter()
	{
		if(null === $this->writeService)
		{
			$this->writeService = MainFactory::create('CustomerGroupWriteService');
		}
		
		return $this->writeService;
	}
}