<?php

namespace HubPublic\ValueObjects;

/**
 * Class CartItem
 *
 * A CartItem contains EAN, name, price, quantity and attributes.
 *
 * @package HubPublic\ValueObjects
 */
class CartItem
{
    /**
     * Cart item ean
     *
     * @var string
     */
    private $ean;
    /**
     * Cart item name
     *
     * @var string
     */
    private $name;
    /**
     * Cart item price
     *
     * @var float
     */
    private $price;
    /**
     * Cart item quantity
     *
     * @var float
     */
    private $quantity;
    /**
     * Cart item attributes
     *
     * @var array
     */
    private $attributes;
    /**
     * CartItem constructor.
     *
     * @param string $ean        Cart item ean
     * @param string $name       Cart item name
     * @param float  $price      Cart item price
     * @param float  $quantity   Cart item quantity
     * @param array  $attributes Cart item attributes
     */
    public function __construct($ean, $name, $price, $quantity, array $attributes)
    {
        $this->ean = trim($ean);
        $this->name = trim($name);
        $this->price = $price;
        $this->quantity = $quantity;
        $this->attributes = $attributes;
    }
    /**
     * Returns the EAN.
     *
     * @return string Cart item EAN
     */
    public function getEan()
    {
        return $this->ean;
    }
    /**
     * Returns the name.
     *
     * @return string Cart item Name
     */
    public function getName()
    {
        return $this->name;
    }
    /**
     * Returns the price.
     *
     * @return float Cart item price
     */
    public function getPrice()
    {
        return $this->price;
    }
    /**
     * Returns the quantity.
     *
     * @return float Cart item quantity
     */
    public function getQuantity()
    {
        return $this->quantity;
    }
    /**
     * Returns the attributes as an array.
     *
     * @return array Cart item attributes
     */
    public function getAttributes()
    {
        return $this->attributes;
    }
}